==> PythUnity-0.71.tar.gz: PythUnity-0.71/setup.py <==

from distutils.core import setup
setup(
  name = 'PythUnity',         # How you named your package folder (MyLib)
  packages = ['PythUnity'],   # Chose the same as "name"
  version = '0.71',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Kinda like Unity but in python',   # Give a short description about your library
  author = 'Dylan Isaac',                   # Type in your name
  author_email = 'disuperguy@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/xCOOLxGUYx/PythUnity',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/xCOOLxGUYx/PythUnity/archive/v_07_1.tar.gz',    # I explain this later on
  keywords = ["Unity", "Python", "Pygame"],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          "pygame"
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)

==> PythUnity-0.72.tar.gz: PythUnity-0.72/setup.py <==

from distutils.core import setup
setup(
  name = 'PythUnity',         # How you named your package folder (MyLib)
  packages = ['PythUnity'],   # Chose the same as "name"
  version = '0.72',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Kinda like Unity but in python',   # Give a short description about your library
  author = 'Dylan Isaac',                   # Type in your name
  author_email = 'disuperguy@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/xCOOLxGUYx/PythUnity',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/xCOOLxGUYx/PythUnity/archive/v_07_2_FIXED.tar.gz',    # I explain this later on
  keywords = ["Unity", "Python", "Pygame"],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          "pygame",
          "numba"
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
